@@ -318,7 +318,7 @@ class Timer {
 public:
   Timer(Context &ctx, std::string name, Timer *parent = nullptr) {
     record = new TimerRecord(name, parent ? parent->record : nullptr);
-    ctx.timer_records.push_back(std::unique_ptr<TimerRecord>(record));
+    ctx.timer_records.emplace_back(record);
   }
 
   Timer(const Timer &) = delete;
@@ -335,23 +335,6 @@ private:
   TimerRecord *record;
 };
 
-//
-// Bit vector
-//
-
-class BitVector {
-public:
-  BitVector() = default;
-  BitVector(u32 size) : vec((size + 7) / 8) {}
-
-  void resize(u32 size) { vec.resize((size + 7) / 8); }
-  bool get(u32 idx) const { return vec[idx / 8] & (1 << (idx % 8)); }
-  void set(u32 idx) { vec[idx / 8] |= 1 << (idx % 8); }
-
-private:
-  std::vector<u8> vec;
-};
-
 //
 // Utility functions
 //
@@ -389,8 +372,14 @@ inline u64 bits(u64 val, u64 hi, u64 lo) {
   return (val >> lo) & ((1LL << (hi - lo + 1)) - 1);
 }
 
-inline i64 sign_extend(u64 val, i64 size) {
-  return (i64)(val << (63 - size)) >> (63 - size);
+// Cast val to a signed N bit integer.
+// For example, sign_extend(x, 32) == (i32)x for any integer x.
+inline i64 sign_extend(u64 val, i64 n) {
+  return (i64)(val << (64 - n)) >> (64 - n);
+}
+
+inline bool is_int(u64 val, i64 n) {
+  return sign_extend(val, n) == val;
 }
 
 template <typename T, typename Compare = std::less<T>>
@@ -906,7 +895,7 @@ public:
     mf->size = size;
     mf->parent = this;
 
-    ctx.mf_pool.push_back(std::unique_ptr<MappedFile>(mf));
+    ctx.mf_pool.emplace_back(mf);
     return mf;
   }
 
@@ -965,7 +954,7 @@ MappedFile *open_file(Context &ctx, std::string path) {
     Fatal(ctx) << error;
 
   if (mf)
-    ctx.mf_pool.push_back(std::unique_ptr<MappedFile>(mf));
+    ctx.mf_pool.emplace_back(mf);
   return mf;
 }
 
